#[repr(u32)]pub enum Color {
Show 32 variants
BloodRed = 6_684_672,
CrimsonRed = 10_027_008,
BostonUniversityRed = 13_369_344,
PersianRed = 13_382_451,
DarkPink = 15_355_016,
CrayolaViolet = 10_040_217,
RebeccaPurple = 6_697_881,
BluePigment = 3_355_545,
TrueBlue = 26_316,
RichElectricBlue = 39_372,
SeaSerpent = 6_737_100,
RybGreen = 7_851_059,
Avocado = 6_723_840,
MetallicGreen = 3_368_448,
BronzeYellow = 6_710_784,
DarkYellow = 10_066_176,
Pear = 13_421_619,
Yellow = 16_776_960,
Sunglow = 16_763_955,
VividGamboge = 16_750_848,
Orange = 16_737_792,
MediumVermilion = 13_395_507,
Coconut = 10_053_171,
PhilippineBronze = 6_697_728,
Black = 0,
SpanishGray = 10_066_329,
LightSteelBlue = 11_255_002,
CarnationPink = 16_625_095,
CookiesAndCream = 15_194_289,
ChineseSilver = 13_421_772,
White = 16_777_215,
Arsenic = 4_342_099,
}Expand description
Colors you can filter by.
Color names found thanks to color-name.com.
This enum’s value is just hex, so you can get the R, G, B values with the following calculations:
let r = (val & 0xFF0000) >> 16let g = (val & 0x00FF00) >> 8let b = (val & 0x0000FF) >> 0
This cannot be customized further as only values allowed by wallhaven can be used.
Variants
BloodRed = 6_684_672
Color with hex code 0x660000
CrimsonRed = 10_027_008
Color with hex code 0x990000
BostonUniversityRed = 13_369_344
Color with hex code 0xcc0000
PersianRed = 13_382_451
Color with hex code 0xcc3333
DarkPink = 15_355_016
Color with hex code 0xea4c88
CrayolaViolet = 10_040_217
Color with hex code 0x993399
RebeccaPurple = 6_697_881
Color with hex code 0x663399
BluePigment = 3_355_545
Color with hex code 0x333399
TrueBlue = 26_316
Color with hex code 0x0066cc
RichElectricBlue = 39_372
Color with hex code 0x0099cc
SeaSerpent = 6_737_100
Color with hex code 0x66cccc
RybGreen = 7_851_059
Color with hex code 0x77cc33
Avocado = 6_723_840
Color with hex code 0x669900
MetallicGreen = 3_368_448
Color with hex code 0x336600
BronzeYellow = 6_710_784
Color with hex code 0x666600
DarkYellow = 10_066_176
Color with hex code 0x999900
Pear = 13_421_619
Color with hex code 0xcccc33
Yellow = 16_776_960
Color with hex code 0xffff00
Sunglow = 16_763_955
Color with hex code 0xffcc33
VividGamboge = 16_750_848
Color with hex code 0xff9900
Orange = 16_737_792
Color with hex code 0xff6600
MediumVermilion = 13_395_507
Color with hex code 0xcc6633
Coconut = 10_053_171
Color with hex code 0x996633
PhilippineBronze = 6_697_728
Color with hex code 0x663300
Black = 0
Color with hex code 0x000000
SpanishGray = 10_066_329
Color with hex code 0x999999
LightSteelBlue = 11_255_002
Color with hex code 0xABBCDA
CarnationPink = 16_625_095
Color with hex code 0xFDADC7
CookiesAndCream = 15_194_289
Color with hex code 0xE7D8B1
ChineseSilver = 13_421_772
Color with hex code 0xcccccc
White = 16_777_215
Color with hex code 0xffffff
Arsenic = 4_342_099
Color with hex code 0x424153