Error

Enum Error 

pub enum Error {
    InvalidApiKey(InvalidHeaderValue),
    UrlParsingError(ParseError),
    BuildingClient(Error),
    SendingRequest(Error),
    DecodingJson(Error),
    UnknownRequestError(Error),
}
Possible errors inside the wallhaven-rs crate

Variants



InvalidApiKey(InvalidHeaderValue)

Returned when an invalid api key is provided to WallhavenClient::with_key



UrlParsingError(ParseError)

Returned when a request fails to build the url from the provided parameters, usually means the parameters are wrong



BuildingClient(Error)

Returned when building WallhavenClient

This error is thrown when building the rewqest client, this means that its probably the library’s fault if this happens (it probably will not happen though) and you should open an issue!



SendingRequest(Error)

There was some error while sending the request, you should match the underlying reqwest::Error further



DecodingJson(Error)

There was an error decoding the JSON, but the response was received successfully.

Its an error either on wallhaven’s side, if they sent a wrong json, or our side, if we wrote a bad model



UnknownRequestError(Error)

Some request error that isn’t neither Error::SendingRequest nor Error::DecodingJson

You can match further the underlying reqwest::Error