pub enum ToplistRange {
OneDay,
ThreeDays,
OneWeek,
OneMonth,
ThreeMonths,
SixMonths,
OneYear,
}Expand description
The time span for the toplist.
For example, ToplistRange::OneDay will show the top wallpapers in the last 24h.
This cannot be customized further as only values allowed by wallhaven can be used
Variants
OneDay
A time span of one day
ThreeDays
A time span of three days
OneWeek
A time span of one week
OneMonth
A time span of one month
ThreeMonths
A time span of three months
SixMonths
A time span of six months
OneYear
A time span of one year