pub enum UserGroup {
User,
Moderator,
SeniorModerator,
Administrator,
Developer,
Owner,
}Expand description
The group the user belongs to, for example User, Moderator…
For more informations, check out the website
Variants
User
A normal user, the group you will be assigned to on account creation
Moderator
A moderator
SeniorModerator
A senior moderator
There is not a lot of information on how to get this role, I’m guessing you get this from being a moderator for enough time
Administrator
An administrator
There is not a lot of information on how to get this role
Developer
One of the website’s developers
Owner
The owner (and main developer) of the website
The only user with this role should be AksumkA