pub struct Meta {
pub current_page: u64,
pub last_page: u64,
pub per_page: u64,
pub total: u64,
pub query: Option<Query>,
pub seed: Option<String>,
}Expand description
Meta informations for the search results, used mostly to continue the search
Fields
current_page: u64The current page
last_page: u64The last page (e.g. page count)
per_page: u64How many wallpapers per page
total: u64Total wallpapers count
Meaning every page, except the last, will have total wallpapers, you can know how many there are in the last by doing:
(last_page * per_page) - total
query: Option<Query>The query information, see Query variants for more informations
seed: Option<String>Random seed used when using SortingType::Random
This can be fed back into the search request to not repeat wallpapers