SearchRequestBuilder

Struct SearchRequestBuilder 

pub struct SearchRequestBuilder<S: State = Empty> { /* private fields */ }
Use builder syntax to set the inputs and finish with build_internal().

Implementations

Source

impl<S: State> SearchRequestBuilder<S>

pub fn query( self, value: Vec<SearchQueryItem>, ) -> SearchRequestBuilder<SetQuery<S>>
where S::Query: IsUnset,

Optional (Some / Option setters).

A list of items of which the query is composed of

See SearchQueryItem for more information

pub fn maybe_query( self, value: Option<Vec<SearchQueryItem>>, ) -> SearchRequestBuilder<SetQuery<S>>
where S::Query: IsUnset,

Optional (Some / Option setters).

A list of items of which the query is composed of

See SearchQueryItem for more information

pub fn categories( self, value: Categories, ) -> SearchRequestBuilder<SetCategories<S>>
where S::Categories: IsUnset,

Optional (Some / Option setters).

Turn categories on or off

pub fn maybe_categories( self, value: Option<Categories>, ) -> SearchRequestBuilder<SetCategories<S>>
where S::Categories: IsUnset,

Optional (Some / Option setters).

Turn categories on or off

pub fn purity(self, value: Purities) -> SearchRequestBuilder<SetPurity<S>>
where S::Purity: IsUnset,

Optional (Some / Option setters).

Turn categories on or off, NSFW requires a valid api key

pub fn maybe_purity( self, value: Option<Purities>, ) -> SearchRequestBuilder<SetPurity<S>>
where S::Purity: IsUnset,

Optional (Some / Option setters).

Turn categories on or off, NSFW requires a valid api key

pub fn sorting(self, value: SortingType) -> SearchRequestBuilder<SetSorting<S>>
where S::Sorting: IsUnset,

Optional (Some / Option setters).

The sorting type.

pub fn maybe_sorting( self, value: Option<SortingType>, ) -> SearchRequestBuilder<SetSorting<S>>
where S::Sorting: IsUnset,

Optional (Some / Option setters).

The sorting type.

pub fn order(self, value: SortingOrder) -> SearchRequestBuilder<SetOrder<S>>
where S::Order: IsUnset,

Optional (Some / Option setters).

The sorting order

pub fn maybe_order( self, value: Option<SortingOrder>, ) -> SearchRequestBuilder<SetOrder<S>>
where S::Order: IsUnset,

Optional (Some / Option setters).

The sorting order

pub fn toplist_range( self, value: ToplistRange, ) -> SearchRequestBuilder<SetToplistRange<S>>
where S::ToplistRange: IsUnset,

Optional (Some / Option setters).

The toplist range.

Sorting MUST be set to SortingType::Toplist

pub fn maybe_toplist_range( self, value: Option<ToplistRange>, ) -> SearchRequestBuilder<SetToplistRange<S>>
where S::ToplistRange: IsUnset,

Optional (Some / Option setters).

The toplist range.

Sorting MUST be set to SortingType::Toplist

pub fn at_least(self, value: Resolution) -> SearchRequestBuilder<SetAtLeast<S>>
where S::AtLeast: IsUnset,

Optional (Some / Option setters).

Minimum resolution allowed

pub fn maybe_at_least( self, value: Option<Resolution>, ) -> SearchRequestBuilder<SetAtLeast<S>>
where S::AtLeast: IsUnset,

Optional (Some / Option setters).

Minimum resolution allowed

pub fn resolutions( self, value: Vec<Resolution>, ) -> SearchRequestBuilder<SetResolutions<S>>
where S::Resolutions: IsUnset,

Optional (Some / Option setters).

List of exact wallpaper resolutions

pub fn maybe_resolutions( self, value: Option<Vec<Resolution>>, ) -> SearchRequestBuilder<SetResolutions<S>>
where S::Resolutions: IsUnset,

Optional (Some / Option setters).

List of exact wallpaper resolutions

pub fn ratios( self, value: Vec<AspectRatio>, ) -> SearchRequestBuilder<SetRatios<S>>
where S::Ratios: IsUnset,

Optional (Some / Option setters).

List of aspect ratios

pub fn maybe_ratios( self, value: Option<Vec<AspectRatio>>, ) -> SearchRequestBuilder<SetRatios<S>>
where S::Ratios: IsUnset,

Optional (Some / Option setters).

List of aspect ratios

pub fn color(self, value: Color) -> SearchRequestBuilder<SetColor<S>>
where S::Color: IsUnset,

Optional (Some / Option setters).

Search by color

pub fn maybe_color( self, value: Option<Color>, ) -> SearchRequestBuilder<SetColor<S>>
where S::Color: IsUnset,

Optional (Some / Option setters).

Search by color

pub fn page(self, value: u64) -> SearchRequestBuilder<SetPage<S>>
where S::Page: IsUnset,

Optional (Some / Option setters).

Pagination, from 1->inf

(Not actually infinite)

pub fn maybe_page(self, value: Option<u64>) -> SearchRequestBuilder<SetPage<S>>
where S::Page: IsUnset,

Optional (Some / Option setters).

Pagination, from 1->inf

(Not actually infinite)

pub fn seed(self, value: String) -> SearchRequestBuilder<SetSeed<S>>
where S::Seed: IsUnset,

Optional (Some / Option setters).

Optional seed for random results

pub fn maybe_seed( self, value: Option<String>, ) -> SearchRequestBuilder<SetSeed<S>>
where S::Seed: IsUnset,

Optional (Some / Option setters).

Optional seed for random results

Source

impl<S: IsComplete> SearchRequestBuilder<S>

pub fn build(self) -> Result<SearchRequest, String>

Builds the request.

Errors

Throws an error if toplist_range is set and sorting isn’t SortingType::Toplist