Tag

Struct Tag 

pub struct Tag {
    pub id: u64,
    pub name: String,
    pub alias: String,
    pub category_id: u64,
    pub category: String,
    pub purity: Purities,
    pub created_at: DateTime,
}
A tag to represent a wallpaper, which is itself categorized into categories

Fields

id: u64

This tag’s id

name: String

The precise tag name

alias: String

An alias for this tag’s name, used for fuzzy search

category_id: u64

This tag’s category’s id

Each tag is part of a category, for example, if two tags have the same category id, it means they are related somehow

For example, the weapon tag has a category_id of 60 (which corresponds to a category = “Military & Weapons”)

In the same way, the arrows tag has the same category_id (thus, the same category)

Note

  • There are a lot of tag categories, like, A LOT. Its not feasible to add every one of them to an enum, unfortunately.
  • To my knowledge, there is no way to fetch tags from the api. I am asking the developers though!
category: String

A string representation of the category_id, in english

See category_id for more informations

purity: Purities

The general purity of the tag

As far as I’m aware of, on tags this purity can either be sfw or nsfw, no sketchy. Do not trust this information, and if you prove me wrong please fill an issue or make a PR! (Be sure to put an example wallpaper id for me to test)

Even if the type is Purities, dont be fooled:

It actually can only be one purity!

created_at: DateTime

The date of creation of this tag