pub struct UserCollection {
pub id: u64,
pub label: String,
pub views: u64,
pub public: bool,
pub count: u64,
}Expand description
An user’s collection of wallpapers
User collections are just a list of wallpaper of some category (categorized by the user that created it)
“Favorite wallpapers” is just a private collection, you can find it under the name “Default”
Fields
id: u64The collection’s id
label: StringThe collection’s name
views: u64How many times this collection was seen
public: boolWhether this collection is private or not
count: u64How many wallpapers are contained in this collection