pub struct UserSettings {
pub thumb_size: ThumbnailResolution,
pub per_page: u64,
pub purity: Purities,
pub categories: Categories,
pub resolutions: Vec<Resolution>,
pub aspect_ratios: Vec<AspectRatio>,
pub toplist_range: ToplistRange,
pub tag_blacklist: Vec<String>,
pub user_blacklist: Vec<String>,
pub ai_art_filter: bool,
}Expand description
Represents user settings, mostly the default search settings
Fields
thumb_size: ThumbnailResolutionThe default wallpaper thumbnail resolution
per_page: u64How many wallpapers per page by default
purity: PuritiesPurities used by default when searching.
See Purities
categories: CategoriesCategories used by default when searching.
See Categories
resolutions: Vec<Resolution>A list of resolutions that will be included by default when searching.
See Resolution
aspect_ratios: Vec<AspectRatio>A list of aspect ratios that will be included by default when searching.
See AspectRatio
toplist_range: ToplistRangeThe toplist range used by default when searching.
See ToplistRange
tag_blacklist: Vec<String>A list of tags that are excluded from all searches and listings
user_blacklist: Vec<String>A list of usernames that are excluded from all searches and listings
ai_art_filter: boolIf AI art is filtered out.