pub enum Resolution {
Show 23 variants
R1280x720,
R1280x800,
R1280x960,
R1280x1024,
R3440x1440,
R1600x900,
R1600x1000,
R1600x1200,
R1600x1280,
R3840x1600,
R1920x1080,
R1920x1200,
R1920x1440,
R1920x1536,
R2560x1080,
R2560x1440,
R2560x1600,
R2560x1920,
R2560x2048,
R3840x2160,
R3840x2400,
R3840x2880,
R3840x3072,
}Expand description
Resolutions you can filter by.
You can check out Resolution::dimensions for numerical values.
This cannot be customized further as only values allowed by wallhaven can be used.
Variants
R1280x720
A resolution of 1280 by 720 pixels
R1280x800
A resolution of 1280 by 800 pixels
R1280x960
A resolution of 1280 by 960 pixels
R1280x1024
A resolution of 1280 by 1024 pixels
R3440x1440
A resolution of 3440 by 1440 pixels
R1600x900
A resolution of 1600 by 900 pixels
R1600x1000
A resolution of 1600 by 1000 pixels
R1600x1200
A resolution of 1600 by 1200 pixels
R1600x1280
A resolution of 1600 by 1280 pixels
R3840x1600
A resolution of 3840 by 1600 pixels
R1920x1080
A resolution of 1920 by 1080 pixels
R1920x1200
A resolution of 1920 by 1200 pixels
R1920x1440
A resolution of 1920 by 1440 pixels
R1920x1536
A resolution of 1920 by 1536 pixels
R2560x1080
A resolution of 2560 by 1080 pixels
R2560x1440
A resolution of 2560 by 1440 pixels
R2560x1600
A resolution of 2560 by 1600 pixels
R2560x1920
A resolution of 2560 by 1920 pixels
R2560x2048
A resolution of 2560 by 2048 pixels
R3840x2160
A resolution of 3840 by 2160 pixels
R3840x2400
A resolution of 3840 by 2400 pixels
R3840x2880
A resolution of 3840 by 2880 pixels
R3840x3072
A resolution of 3840 by 3072 pixels
Implementations
Sourceimpl Resolution
impl Resolution
Sourcepub const fn dimensions(&self) -> (u32, u32)
pub const fn dimensions(&self) -> (u32, u32)
A shorthand for a match case returning the actual width and height of the resolution
Basically, for R(W)x(H) will return (W, H)